FirebaseConfig class
Properties
-
config
→ Map<String, dynamic>
-
{
'name': 'name',
'version': 'version',
'author': 'author',
'description': 'description',
'package': 'package',
'token': errorToken,
'platform': Platform.isAndroid ? 'android' : 'ios',
}
final
-
credentialsPath
→ String
-
path assets to json file v1
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
projectId
→ String
-
project id from firebase console
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetToken
→ String
-
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited