HandlerzController<T> class
abstract
Constructors
- HandlerzController(Handlerz handlerz)
Properties
- currentClass → T
-
no setter
- handlerz → Handlerz
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addClass(
dynamic controller) → dynamic -
get(
dynamic function(T)) → dynamic -
getAsync(
dynamic function(T)) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited